/***************************************************************************
**
**  This file is part of QGpGuiWave.
**
**  QGpGuiWave is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpGuiWave is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-02-18
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "DispersionPlotProxy.h"

namespace QGpGuiWave {

  /*!
    \class DispersionPlotProxy DispersionPlotProxy.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  void DispersionPlotProxy::setYAxisProperties(Axis * a)
  {
    TRACE;
    a->setScaleType(Scale::InverseLog);
    a->setAutoTicks(false);
    a->setMajorTicks(1.0);
    a->setMinorTicks(0.2);
    a->setRange(1.0/3500.0, 1.0/50.0); // in slowness
  }

} // namespace QGpGuiWave

